@@ -18,10 +18,9 @@ namespace MyGUI
 	class MYGUI_EXPORT IItemContainer
 	{
 	public:
-		IItemContainer() { }
 		virtual ~IItemContainer() { }
 
-		virtual size_t _getItemCount()
+		virtual size_t _getItemCount() const
 		{
 			return 0;
 		}
@@ -30,13 +29,13 @@ namespace MyGUI
 
 		virtual void _removeItemAt(size_t _index) { }
 
-		virtual Widget* _getItemAt(size_t _index)
+		virtual Widget* _getItemAt(size_t _index) const
 		{
 			return nullptr;
 		}
 
 		virtual void _setItemNameAt(size_t _index, const UString& _name) { }
-		virtual const UString& _getItemNameAt(size_t _index)
+		virtual const UString& _getItemNameAt(size_t _index) const
 		{
 			return Constants::getEmptyUString();
 		}
