@@ -20,10 +20,10 @@ namespace MyGUI
 {
 
 	class MYGUI_EXPORT LayerManager :
-		public Singleton<LayerManager>,
 		public IUnlinkWidget,
 		public MemberObsolete<LayerManager>
 	{
+		MYGUI_SINGLETON_DECLARATION(LayerManager);
 	public:
 		typedef std::vector<ILayer*> VectorLayer;
 		typedef Enumerator<VectorLayer> EnumeratorLayer;
@@ -66,10 +66,10 @@ namespace MyGUI
 
 		size_t getLayerCount() const;
 
-		ILayer* getLayer(size_t _index);
+		ILayer* getLayer(size_t _index) const;
 
 		/** Get top visible and enabled widget at specified position */
-		Widget* getWidgetFromPoint(int _left, int _top);
+		Widget* getWidgetFromPoint(int _left, int _top) const;
 
 		/** Render all layers to specified target */
 		void renderToTarget(IRenderTarget* _target, bool _update);
@@ -80,7 +80,7 @@ namespace MyGUI
 
 	private:
 		void _load(xml::ElementPtr _node, const std::string& _file, Version _version);
-		void _unlinkWidget(Widget* _widget);
+		void _unlinkWidget(Widget* _widget) override;
 
 		ILayer* _createLayerObject(const std::string& _type);
 
